#!/usr/bin/python
# -*- coding: utf-8 -*-
# @version        : 1.0
# @Create Time    : 2025/04/03 10:30
# @File           : crud.py
# @IDE            : PyCharm
# @desc           : 数据访问层
from sqlalchemy.ext.asyncio import AsyncSession
from core.crud import DalBase
from . import schemas, models



class ProjectDetectDal(DalBase):

    def __init__(self, db: AsyncSession):
        super(ProjectDetectDal, self).__init__()
        self.db = db
        self.model = models.ProjectDetect
        self.schema = schemas.ProjectDetectSimpleOut


class ProjectDetectImgDal(DalBase):

    def __init__(self, db: AsyncSession):
        super(ProjectDetectImgDal, self).__init__()
        self.db = db
        self.model = models.ProjectDetectImg
        self.schema = schemas.ProjectDetectImgSimpleOut


class ProjectDetectLogDal(DalBase):

    def __init__(self, db: AsyncSession):
        super(ProjectDetectLogDal, self).__init__()
        self.db = db
        self.model = models.ProjectDetectLog
        self.schema = schemas.ProjectDetectLogSimpleOut


class ProjectDetectLogImgDal(DalBase):

    def __init__(self, db: AsyncSession):
        super(ProjectDetectLogImgDal, self).__init__()
        self.db = db
        self.model = models.ProjectDetectLogImg
        self.schema = schemas.ProjectDetectLogImgSimpleOut
